/*** * * *  a s t r o l i b . c                  * * * ***/
/*** * * *     * * * ***/
/*** * * *    "Practical Astronomy  * * * ***/
/*** * * *  with your Calculator - Peter Duffett * * * ***/
/*** * * *                 Smith                 * * * ***/

/*(c) 2003,  .  - Stefanos S. Kozanis*/
/*http://users.ntua.gr/soulman/						 */
/*http://users.ntua.gr/soulman/astrolib/ (astrolib)  */
/*   : S.Kozanis@itia.ntua.gr*/

#include <math.h>
#include "astrolib.h"

/**************************/
/*   */
/**************************/

int MOD(int n, int d)
{
	return	n-d*(n/d);
}



/********************************************/
/*  					*/
/********************************************/





/* () ,      */
double JDGreekEaster(double year)
{
	double JD;
	JD=YYMMDD2JD(year,4.000,1.000);
	JD+=(double)(MOD(19*MOD((int)year,19)+16,30)+MOD(2*MOD((int)year,4)+4*MOD((int)year,7)+6*MOD(19*MOD((int)year,19)+16,30),7)+3);
	return JD-1.000;
}





/* ,      */
double JDEaster(double year) /* */
{
	double JD;
	JD=YYMMDD2JD(year,4.000,1.000);

	return JD;
}





/*   --  JD     */
/*   year  month   */
/*   int      */
/*   double			               */
double YYMMDD2JD(double year, double month, double day)
{
	int A,B,C,D;
	double mt,yt;
	if(month<3)
	{
		yt=year-1.00000;
		mt=month+12.0000;
	}
	else
	{
		yt=year;
		mt=month;
	}
        
/*       */
	A=(int)(yt*0.010);
	if((year+month/12.000+day/365.000)>=
           (1582.000+10.000/12.000+15.000/365.000))
		B=2-A+(int)((double)A*0.25000);
	else
		B=0;

/*   yt<0 ( ??) */
	if(yt<0.000)
		C=(int)((365.25*yt)-0.75);
	else
		C=(int)(365.25*yt);

	D=(int)(30.6001*(mt+1));
	
	return (double)(B+C+D)+day+1720994.5;
}





/*   JD  --     */
void JD2YYMMDD(double JD, double* year, double* month, double* day)
{
	int I,A,B,C,D,E,G;
	double F;
	JD=JD+0.5000;
	I=(int)JD;
	F=JD-(double)I;
	
	A=(int)( ((double)I-1867216.25)/36524.25 );
	
	if(I>2299160)
		B=I+1+A-(int)((double)A*0.25000);
	else
		B=I;

	C=B+1524;
	D=(int)(((double)C-122.100)/365.25);
	E=(int)((double)D*365.25);
	G=(int)(((double)C-(double)E)/30.6001);
	
	*day=(double)(C-E-(int)(30.6001*(double)G))+F;
	if(G<=13)
		*month=(double)G-1.000;
	else
		*month=(double)G-13.000;
	if(*month>2.000)
		*year=(double)D-4716.000;
	else
		*year=(double)D-4715.000;
}





/*        JD      */
/*        0 () */
/*  6 ()                                            */
int FindDayOfTheWeek(double JD)
{
	double A;
	double f;

	JD-=0.500;
	JD=(double)((int)JD);
	JD+=0.500;

	A=(JD+1.5000)/7.0000;
	f=A-(double)((int)A);
	f=f*7.000;
	return (int)(f+0.5000);
}





/*  --    */
double HHMMSS2DecHour(double hour, double minute, double second)
{
	return hour+minute/60.000+second/3600.0000;
}





/*     -- */
double DecHour2HHMMSS(double DecHour, double* minute, double* second)
{
	double hour;
	hour=(double)((int)DecHour);
	DecHour-=hour;
	DecHour=DecHour*60.0000;
	*minute=(double)((int)DecHour);
	DecHour-=*minute;
	DecHour=DecHour*60.0000;
	*second=DecHour;
	return hour;
}





/*   -      */
double DDDecHour2DecDay(double day, double hour)
{
	return day+hour/24.000;
}




/*     ,  */
double DecDay2DDDecHour(double DecDay, double* hour)
{
	double day;
	day=(double)((int)DecDay);
	DecDay-=day;
	DecDay=DecDay*24.000;
	*hour=DecDay;
	return day;
}





/*     UTC */
double LT2UTC(double TZ,double hour)
{
	hour-=TZ;

	return hour;
}





/*  UTC   */
double UTC2LT(double TZ, double hour)
{
	hour+=TZ;

	return hour;
}





/*  UTC  GST (Greenwich Sidereal Time) Assume UT=UTC=GMT*/
double UTC2GST(double JD)
{
	double UT,S,T,T0;
	
	UT=JD-(double)( (int)(JD-0.500) )-0.500;
	JD-=UT;
	UT=UT*24.000;

	S=JD-2451545.000;
	T=S/36525.000;
	T0=6.697374558+(2400.0513369072+(0.0000258622-T*1.722208e-9)*T)*T;
	while(T0>=24.000)
		T0-=24.000;
	while(T0<0.000)
		T0+=24.000;
	UT=UT*1.002737909+T0;
	if(UT>=24.000)
		UT-=24.000;
	if(UT<0.000)
		UT+=24.000;
	return UT;
}





/*   GST  UTC*/
double GST2UTC(double JD, double GST)
{
	double S,T,T0;
	
	S=JD-2451545.000;
	T=S/36525.000;
	T0=6.697374558+(2400.051336*T)+(0.000025862*T*T);
	while(T0>=24.000)
		T0-=24.000;
	while(T0<0.000)
		T0+=24.000;
	GST-=T0;
	if(GST>=24.000)
		GST-=24.000;
	if(GST<0.000)
		GST+=24.000;
	GST=GST*0.9972695663;

	return GST;
}
	




/*   GST  LST (Local Sidereal Time)*/
double GST2LST(double Longitude, double GST)//Longitude in radials
{
	Longitude=Longitude*3.000/atan(1.0000);
	GST+=Longitude;
	if(GST>=24.000)
		GST-=24.000;
	if(GST<0.000)
		GST+=24.000;
	return GST;
}




/*   LST  GST */
double LST2GST(double Longitude, double LST)
{
	Longitude=Longitude*3.000/atan(1.0000);
	LST-=Longitude;
	if(LST>=24.000)
		LST-=24.000;
	if(LST<0.000)
		LST+=24.000;
	return LST;	
}





/************************************************/
/*                        */
/************************************************/

/*    */
void SystemTransform(double mi,double ni, double* theta, double* psi, double A[3][3])
{

	double M[3],X[3];
	int i,j;
	double theta0;
	
	/*  ,  mi,ni*/
	X[0]=cos(mi)*cos(ni);
	X[1]=sin(mi)*cos(ni);
	X[2]=sin(ni);

	/*  */
	for(i=0;i<3;i++)
	{
		M[i]=0.000000;
		for(j=0;j<3;j++)
		{
			M[i]+=A[i][j]*X[j];
		}
	}
	
	/*  */
	*psi=asin(M[2]);
	
	/*        /*
	/*    */
	if(fabs(M[0])<1.000e-12)
	{
		if(M[0]>=0.000)
			*theta=0.500*PI;
		else
			*theta=1.500*PI;
	}
	else
	{
		theta0=atan(fabs(M[1]/M[0]));
		if(M[0]>=0.000)
		{
			if(M[1]>=0)
				*theta=theta0;
			else
				*theta=2.000*PI-theta0;
		}
		else
		{
			if(M[1]>=0)
				*theta=PI-theta0;
			else
				*theta=PI+theta0;
		}
	}
}





/*            */
void PrecessionTransform(double JD1,double JD2,int n,double ra1[],double dec1[],double ra2[],double dec2[])
{
	double T,zita_a,z_a,theta_a,A[3][3],B[3][3];
	double CX,SX,CZ,SZ,CT,ST;
	double tmp_ra,tmp_dec;
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

/*     ,    epoch J2000.0, */
/*     J2000.0  */
	if(JD1!=2451545.000)
	{
		T=(JD1-2451545.000)/36525.000;
		zita_a=(0.01118086019+(1.464331242e-6+8.72664626e-8*T)*T)*T;
		z_a=(0.01118086019+(5.307546255e-6+8.901179185e-8*T)*T)*T;
		theta_a=(0.00971717297-(2.068215164e-6+2.024581932e-7*T)*T)*T;
		
		CX=cos(zita_a);
		SX=sin(zita_a);
		CZ=cos(z_a);
		SZ=sin(z_a);
		CT=cos(theta_a);
		ST=sin(theta_a);
		B[0][0]=CX*CT*CZ-SX*SZ,B[0][1]=CX*CT*SZ+SX*CZ ,B[0][2]=CX*ST;
		B[1][0]=-1.000*SX*CT*CZ-CX*SZ ,B[1][1]=-1.000*SX*CT*SZ+CX*CZ ,B[1][2]= -1.000*SX*ST;
		B[2][0]=-1.000*ST*CZ ,B[2][1]=-1.000*ST*SZ ,B[2][2]=CT;
	}

/*      JD2     */
/*   ,,    */
	T=(JD2-2451545.000)/36525.000;
	zita_a=(0.01118086019+(1.464331242e-6+8.72664626e-8*T)*T)*T;
	z_a=(0.01118086019+(5.307546255e-6+8.901179185e-8*T)*T)*T;
	theta_a=(0.00971717297-(2.068215164e-6+2.024581932e-7*T)*T)*T;

	CX=cos(zita_a);
	SX=sin(zita_a);
	CZ=cos(z_a);
	SZ=sin(z_a);
	CT=cos(theta_a);
	ST=sin(theta_a);
	A[0][0]=CX*CT*CZ-SX*SZ,A[1][0]=CX*CT*SZ+SX*CZ ,A[2][0]=CX*ST;
	A[0][1]=-1.000*SX*CT*CZ-CX*SZ ,A[1][1]=-1.000*SX*CT*SZ+CX*CZ ,A[2][1]= -1.000*SX*ST;
	A[0][2]=-1.000*ST*CZ ,A[1][2]=-1.000*ST*SZ ,A[2][2]=CT;

	for(i=0;i<n;i++){
	
		if(JD1!=2451545.000)
		{
			SystemTransform(ra1[i],dec1[i],&tmp_ra,&tmp_dec,B);
		}
		else
		{
			tmp_ra=ra1[i];
			tmp_dec=dec1[i];
		}

		SystemTransform(tmp_ra,tmp_dec,&ra2[i],&dec2[i],A);

	}
}





/*      */
void radec2azalt(double LST, double latitude,int n,double ra[],double dec[],double az[],double alt[])
{
	double A[3][3];
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

	/* ,  LST  . */
	A[0][0]=-1.000*sin(latitude)*cos(LST);
	A[0][1]=-1.000*sin(latitude)*sin(LST);
	A[0][2]=cos(latitude);
	A[1][0]=-1.000*sin(LST);
	A[1][1]=cos(LST);
	A[1][2]=0.000;
	A[2][0]=cos(latitude)*cos(LST);
	A[2][1]=cos(latitude)*sin(LST);
	A[2][2]=sin(latitude);

	for(i=0;i<n;i++)
	{
		SystemTransform(ra[i],dec[i],&az[i],&alt[i],A);
	}
}





/*     */
void azalt2radec(double LST, double latitude,int n,double az[],double alt[],double ra[],double dec[])
{
	double A[3][3];
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

	/* ,  LST  . */
	A[0][0]=-1.000*sin(latitude)*cos(LST);
	A[1][0]=-1.000*sin(latitude)*sin(LST);
	A[2][0]=cos(latitude);
	A[0][1]=-1.000*sin(LST);
	A[1][1]=cos(LST);
	A[2][1]=0.000;
	A[0][2]=cos(latitude)*cos(LST);
	A[1][2]=cos(latitude)*sin(LST);
	A[2][2]=sin(latitude);

	for(i=0;i<n;i++)
	{
		SystemTransform(az[i],alt[i],&ra[i],&dec[i],A);
	}
}





/*     */
double obliquity(double JD)
{
	double T;

	/*  ... Julian    JD2000*/
	T=JD-2451545.000;
	T=T/36525.000;
	return PI/180.000*(23.000+26.000/60.000+21.448/3600.000)-(PI/648000.0)*( 46.8150+(0.00059-0.001813*T)*T )*T;
}





/*     */
void radec2lamdabeta(double obliquity,int n,double ra[],double dec[],double lamda[],double beta[])
{
	double A[3][3];
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

	/*         */
	A[0][0]=1.000;
	A[0][1]=0.000;
	A[0][2]=0.000;
	A[1][0]=0.000;
	A[1][1]=cos(obliquity);
	A[1][2]=1.000*sin(obliquity);
	A[2][0]=0.000;
	A[2][1]=-1.000*sin(obliquity);
	A[2][2]=cos(obliquity);

	for(i=0;i<n;i++)
	{
		SystemTransform(ra[i],dec[i],&lamda[i],&beta[i],A);
	}	
}





/*    */
void lamdabeta2radec(double obliquity,int n,double lamda[],double beta[],double ra[],double dec[])
{
	double A[3][3];
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

	/*         */
	A[0][0]=1.000;
	A[1][0]=0.000;
	A[2][0]=0.000;
	A[0][1]=0.000;
	A[1][1]=cos(obliquity);
	A[2][1]=1.000*sin(obliquity);
	A[0][2]=0.000;
	A[1][2]=-1.000*sin(obliquity);
	A[2][2]=cos(obliquity);

	for(i=0;i<n;i++)
	{
		SystemTransform(lamda[i],beta[i],&ra[i],&dec[i],A);
	}	
}




/*     */
void radec2galactic(int n,double ra[],double dec[],double lamda[],double beta[])
{
	double A[3][3];
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

	/*  */
	A[0][0]=-0.0669887;
	A[0][1]=-0.8727558;
	A[0][2]=-0.4835389;
	A[1][0]= 0.4927285;
	A[1][1]=-0.4503470;
	A[1][2]= 0.7445846;
	A[2][0]=-0.8676008;
	A[2][1]=-0.1883746;
	A[2][2]= 0.4601998;

	for(i=0;i<n;i++)
	{
		SystemTransform(ra[i],dec[i],&lamda[i],&beta[i],A);
	}	
}





/*    */
void galactic2radec(int n,double lamda[],double beta[],double ra[],double dec[])
{
	double A[3][3];
	int i;

	if(n<1)		/*   n<1,    1 */
		n=1;

	/*  */
	A[0][0]=-0.0669887;
	A[1][0]=-0.8727558;
	A[2][0]=-0.4835389;
	A[0][1]= 0.4927285;
	A[1][1]=-0.4503470;
	A[2][1]= 0.7445846;
	A[0][2]=-0.8676008;
	A[1][2]=-0.1883746;
	A[2][2]= 0.4601998;

	for(i=0;i<n;i++)
	{
		SystemTransform(lamda[i],beta[i],&ra[i],&dec[i],A);
	}	
}





/*           */
void Transform_radec_nutationANDaberration(char flags,double JD,int n,double ra1[],double dec1[],double ra2[],double dec2[])
{
	int i;
	double T,Omega,L,B,A,dpsi,e,dl,db,sun;

	if(n<1)		/*   n<1,    1 */
		n=1;
	/*  e        */
	e=obliquity(JD);
	dl=0.000;
	db=0.000;

	/*     ... (flags H02)*/
	if(flags&NUTATION){
		T=(JD-2415020.0)/36525;

		A=100.002136*T;
		L=279.6967+360.0*(A-(double)((int)A));
		L=L*PI/180.000;

		B=5.372617*T;
		Omega=259.1833-360.0*(B-(double)((int)B));
		Omega=Omega*PI/180.000;

		/*       */
		e+=(PI/648000.0)*( 9.20*cos(Omega)+0.57*cos(2.0*L) );
		dpsi=(PI/648000.0)*( -17.20*sin(Omega)-1.32*sin(2.0*L) );
	}

	/*     ... (flags H04)*/
	if(flags&ABERRATION)
	{
		/*   */
		sun=sun_longitude(JD);
	}

	/*      */
	radec2lamdabeta(e,n,ra1,dec1,ra2,dec2);
	
	for(i=0;i<n;i++)
	{
		if(flags&NUTATION)
			ra2[i]+=dpsi;/*       (l)*/

		if(flags&ABERRATION)
		{
			if(fabs(dec2[i])<1.5707963)/* ~90   */
				dl=-9.938680463e-5*cos(sun-ra2[i])/cos(dec2[i]);
			db=-9.938680463e-5*sin(sun-ra2[i])*sin(dec2[i]);
			ra2[i]+=dl;/*     */
			dec2[i]+=db;/*    */			
		}
	}
	
	/*     */
	lamdabeta2radec(e,n,ra2,dec2,ra1,dec1);
}





/*        */
/*     .        */
/*         (Transform_radec_nutationANDaberration) */
void Transform_lamdabeta2radec_nutationANDaberration(char flags,double JD,int n,double lamda[],double beta[],double ra[],double dec[])
{
	int i;
	double T,Omega,L,B,A,dpsi,e,dl,db,sun;

	if(n<1)		/*   n<1,    1 */
		n=1;
	e=obliquity(JD);
	dl=0.000;
	db=0.000;

	if(flags&NUTATION){ 
		T=(JD-2415020.0)/36525;

		A=100.002136*T;
		L=279.6967+360.0*(A-(double)((int)A));
		L=L*PI/180.000;

		B=5.372617*T;
		Omega=259.1833-360.0*(B-(double)((int)B));
		Omega=Omega*PI/180.000;

		e+=(PI/648000.0)*( 9.20*cos(Omega)+0.57*cos(2.0*L) );
		dpsi=(PI/648000.0)*( -17.20*sin(Omega)-1.32*sin(2.0*L) );
	}
	
	if(flags&ABERRATION)
	{
		sun=sun_longitude(JD);
	}

	for(i=0;i<n;i++)
	{
		if(flags&NUTATION)
			lamda[i]+=dpsi;

		if(flags&ABERRATION)
		{
			if(fabs(beta[i])<1.5707963)
				dl=-9.938680463e-5*cos(sun-lamda[i])/cos(beta[i]);
			db=-9.938680463e-5*sin(sun-lamda[i])*sin(beta[i]);
			lamda[i]+=dl;
			beta[i]+=db;	
		}
	}
	
	lamdabeta2radec(e,n,lamda,beta,ra,dec);
}





/*  */
double refraction(double  P , double T , double alt)
{
	double R;
	/*alt,   */
	/*T:oC, P:mbar */
	if(alt>0.2617993878)
	{
		R=(PI/180.000)*(0.00452*P*tan(0.500*PI-alt))/(273.000+T);
	}
	else
	{
		alt=alt*180.000/PI;
		R=(PI/180.000)*P*(0.1594+0.0196*alt+0.00002*alt*alt)/((273+T)*(1+0.505*alt+0.0845*alt*alt));
	}
	
	/*  -R,     */
	/*       		  */
	return -1.000*R;
}





/*  (,)   */
void GeocentricParalax(double LST, double latitude, double height, double distance, int n,double ra1[],double dec1[],double ra2[],double dec2[])
{
	/*LST, latitude: radians, height: , distance: km*/
	double rsinf,rcosf,u,r,alpha,delta,H;
	int i;
	u=atan(0.996647*tan(latitude));
	rsinf=0.996647*sin(u)+(height/6378140.000)*sin(latitude);
	rcosf=cos(u)+(height/6378140.000)*cos(latitude);

	r=distance/6378.140;	/*dinstance:km r:earth radi ( )*/

	for(i=0;i<n;i++)
	{
		alpha=ra1[i];
		delta=dec1[i];
		H=LST-alpha;
		ra2[i]=alpha-atan((rcosf*sin(H)) / (r*cos(delta)-rcosf*cos(H)));
		dec2[i]=atan( cos(LST-ra2[i])*(r*sin(delta)-rsinf)/(r*cos(delta)*cos(H)-rcosf) );
	}
}





/*        */
/*      .  */
double JD_from_light_travel_delay(double JD,double distance)
{
	return JD-(distance/LIGHT_SPEED)/(3600.000*24.000);
}





/*********************************************************/
/*                                        */
/*********************************************************/

/*       */
/*     Kepler*/
/*    J1990 (JD=2447891.5) */
double sun_longitude(double JD)
{
	double eg,vg,e,l,M,E,d;
	eg=279.4033035;
	vg=282.768421559;
	e=0.016713319;

	JD=JD-2447891.5;
	
	M=((360.000/365.242191)*JD+eg-vg);
	while(M<0.000)
		M+=360.000;
	while(M>=360.000)
		M-=360.000;
	M=M*PI/180.000;
	E=M;
	do
	{
		d=E-e*sin(E)-M;
		E=E-d/(1-e*cos(E));
	}while(fabs(d)>1.000e-7);
	l=vg+360.000/PI*atan( sqrt( (1+e)/(1-e) )*tan(0.500*E) );
	while(l<0.000)
		l+=360.000;
	while(l>=360.000)
		l-=360.000;
	return l*PI/180.000;
}





/*  -   km*/
double sun_distance(double sun_longitude) 
{
	/*sun longitude  radians */
	double r0,e,ni;
	
	r0=1.495985e8;	/*r0  km*/
	e=0.016713;
	ni=sun_longitude-282.768422*PI/180.000;

	return r0*(1-e*e)/(1+e*cos(ni));
}





/*     radians */
double sun_angular_size(double sun_longitude)
{
	/*sun longitude  radians */
	double theta0,e,ni;
	
	theta0=0.533128*PI/180.000;	/*theta0  radians*/
	e=0.016713;
	ni=sun_longitude-282.768422*PI/180.000;

	return theta0*(1+e*cos(ni))/(1-e*e);
}





/*    Epoch JD1990*/
void calculateMoon(double JD,double Results[6])
{
	/*  Results: */
	/*	0: 	1: 		*/
	/*	2: -	3: (rad)	*/
	/*	4: ()	5: (0.000-1.000)	*/
	double l0,P0,N0,i,e,alpha,theta0;
	double l_sun,M_sun,D,l,Mm,N,Ev,Ae,A3,Mmt,Ec,A4,C;
	double lt,ltt,V,Nt,e_sun,E_sun,y,x,lm,lm0;

	e_sun=0.016713;
	l_sun=sun_longitude(JD);
	E_sun=2*atan( tan(0.5*(l_sun-4.935239984))/sqrt((1+e_sun)/(1-e_sun)) );
	M_sun=E_sun-e_sun*sin(E_sun);

	l0=5.55628443675;
	P0=0.63425980602;
	N0=5.55905006803;
	i=0.08980410152;
	e=0.054900;
	alpha=384401.000;
	theta0=0.00904255085;

	D=JD-2447891.500;

	l=0.22997150422*D+l0;
	while(l<0.000)
		l+=2.000*PI;
	while(l>=2.000*PI)
		l-=2.000*PI;
	Mm=l-0.00194436835*D-P0;
	while(Mm<0.000)
		Mm+=2.000*PI;
	while(Mm>2.000*PI)
		Mm-=2.000*PI;
	N=N0-0.00092421991*D;
	while(N<0.000)
		N+=2.000*PI;
	while(N>=2.000*PI)
		N-=2.000*PI;

	C=l-l_sun;
	Ev=0.02223374934*sin(2*C-Mm);
	Ae=0.00324282175*sin(M_sun);
	A3=0.00645771823*sin(M_sun);
	Mmt=Mm+Ev-Ae-A3;

	Ec=0.10975677534*sin(Mmt);
	A4=0.00373500460*sin(2.000*Mmt);

	lt=l+Ev+Ec-Ae+A4;
	V=0.01148950247*sin(2.000*(lt-l_sun));
	ltt=lt+V;
	Nt=N-0.00279252680*sin(M_sun);

	y=sin(ltt-Nt)*cos(i);
	x=cos(ltt-Nt);

	if(fabs(x)<1.000e-12)
	{
		if(x>=0.000)
			lm=0.500*PI;
		else
			lm=1.500*PI;
	}
	else
	{
		lm0=atan(fabs(y/x));
		if(x>=0.000)
		{
			if(y>=0)
				lm=lm0;
			else
				lm=2.000*PI-lm0;
		}
		else
		{
			if(y>=0)
				lm=PI-lm0;
			else
				lm=PI+lm0;
		}
	}

	Results[0]=lm+Nt;							/* 	*/
	while(Results[0]<0.000)
		Results[0]+=2.000*PI;
	while(Results[0]>=2.000*PI)
		Results[0]-=2.000*PI;
	Results[1]=asin( sin(ltt-Nt) * sin(i) );	/* 	*/
	Results[2]=(1-e*e)/(1+e*cos(Mmt+Ec));		/* -	*/
	Results[3]=theta0/Results[2];				/* 	*/
	Results[2]=Results[2]*alpha;
	Results[4]=ltt-l_sun;						/*	*/
	Results[5]=0.500*(1.000-cos(Results[4]));	/*	*/
}